@@ -14,15 +14,14 @@
 
 import socket
 import time
+from wsgiref import simple_server
 
 import mock
 from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-from oslotest import base as test_base
 import pkg_resources
 from stevedore import extension
-from wsgiref import simple_server
 
 from ironic_python_agent import agent
 from ironic_python_agent import encoding
@@ -31,6 +30,7 @@ from ironic_python_agent.extensions import base
 from ironic_python_agent import hardware
 from ironic_python_agent import inspector
 from ironic_python_agent import netutils
+from ironic_python_agent.tests.unit import base as ironic_agent_base
 from ironic_python_agent import utils
 
 EXPECTED_ERROR = RuntimeError('command execution failed')
@@ -49,7 +49,7 @@ class FakeExtension(base.BaseAgentExtension):
     pass
 
 
-class TestHeartbeater(test_base.BaseTestCase):
+class TestHeartbeater(ironic_agent_base.IronicAgentTest):
     def setUp(self):
         super(TestHeartbeater, self).setUp()
         self.mock_agent = mock.Mock()
@@ -60,10 +60,10 @@ class TestHeartbeater(test_base.BaseTestCase):
             hardware.HardwareManager)
         self.heartbeater.stop_event = mock.Mock()
 
-    @mock.patch('os.read')
-    @mock.patch('select.poll')
-    @mock.patch('ironic_python_agent.agent._time')
-    @mock.patch('random.uniform')
+    @mock.patch('os.read', autospec=True)
+    @mock.patch('select.poll', autospec=True)
+    @mock.patch('ironic_python_agent.agent._time', autospec=True)
+    @mock.patch('random.uniform', autospec=True)
     def test_heartbeat(self, mock_uniform, mock_time, mock_poll, mock_read):
         time_responses = []
         uniform_responses = []
@@ -129,7 +129,7 @@ class TestHeartbeater(test_base.BaseTestCase):
 
 @mock.patch.object(hardware.GenericHardwareManager, '_wait_for_disks',
                    lambda self: None)
-class TestBaseAgent(test_base.BaseTestCase):
+class TestBaseAgent(ironic_agent_base.IronicAgentTest):
 
     def setUp(self):
         super(TestBaseAgent, self).setUp()
@@ -171,8 +171,12 @@ class TestBaseAgent(test_base.BaseTestCase):
         self.assertEqual(pkg_resources.get_distribution('ironic-python-agent')
                          .version, status.version)
 
+    @mock.patch.object(hardware, '_check_for_iscsi', mock.Mock())
+    @mock.patch(
+        'ironic_python_agent.hardware_managers.cna._detect_cna_card',
+        mock.Mock())
     @mock.patch.object(agent.IronicPythonAgent,
-                       '_wait_for_interface')
+                       '_wait_for_interface', autospec=True)
     @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
     @mock.patch('wsgiref.simple_server.make_server', autospec=True)
     def test_run(self, mock_make_server, mock_dispatch, mock_wait):
@@ -199,16 +203,20 @@ class TestBaseAgent(test_base.BaseTestCase):
             self.agent.api,
             server_class=simple_server.WSGIServer)
         wsgi_server.serve_forever.assert_called_once_with()
-        mock_wait.assert_called_once_with()
+        mock_wait.assert_called_once_with(mock.ANY)
         mock_dispatch.assert_called_once_with("list_hardware_info")
         self.agent.heartbeater.start.assert_called_once_with()
 
+    @mock.patch.object(hardware, '_check_for_iscsi', mock.Mock())
+    @mock.patch('ironic_python_agent.hardware_managers.cna._detect_cna_card',
+                mock.Mock())
     @mock.patch.object(agent.IronicPythonAgent,
-                       '_wait_for_interface')
+                       '_wait_for_interface', autospec=True)
     @mock.patch.object(inspector, 'inspect', autospec=True)
     @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
     @mock.patch('wsgiref.simple_server.make_server', autospec=True)
-    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info')
+    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info',
+                       autospec=True)
     def test_run_with_inspection(self, mock_list_hardware, mock_make_server,
                                  mock_dispatch, mock_inspector, mock_wait):
         CONF.set_override('inspection_callback_url', 'http://foo/bar',
@@ -244,16 +252,21 @@ class TestBaseAgent(test_base.BaseTestCase):
             'uuid',
             self.agent.api_client.lookup_node.call_args[1]['node_uuid'])
 
-        mock_wait.assert_called_once_with()
+        mock_wait.assert_called_once_with(mock.ANY)
         mock_dispatch.assert_called_once_with("list_hardware_info")
         self.agent.heartbeater.start.assert_called_once_with()
 
+    @mock.patch.object(hardware, '_check_for_iscsi', mock.Mock())
+    @mock.patch(
+        'ironic_python_agent.hardware_managers.cna._detect_cna_card',
+        mock.Mock())
     @mock.patch.object(agent.IronicPythonAgent,
-                       '_wait_for_interface')
+                       '_wait_for_interface', autospec=True)
     @mock.patch.object(inspector, 'inspect', autospec=True)
     @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
     @mock.patch('wsgiref.simple_server.make_server', autospec=True)
-    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info')
+    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info',
+                       autospec=True)
     def test_run_with_inspection_without_apiurl(self,
                                                 mock_list_hardware,
                                                 mock_make_server,
@@ -296,12 +309,17 @@ class TestBaseAgent(test_base.BaseTestCase):
         self.assertFalse(mock_wait.called)
         self.assertFalse(mock_dispatch.called)
 
+    @mock.patch.object(hardware, '_check_for_iscsi', mock.Mock())
+    @mock.patch(
+        'ironic_python_agent.hardware_managers.cna._detect_cna_card',
+        mock.Mock())
     @mock.patch.object(agent.IronicPythonAgent,
-                       '_wait_for_interface')
+                       '_wait_for_interface', autospec=True)
     @mock.patch.object(inspector, 'inspect', autospec=True)
     @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
     @mock.patch('wsgiref.simple_server.make_server', autospec=True)
-    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info')
+    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info',
+                       autospec=True)
     def test_run_without_inspection_and_apiurl(self,
                                                mock_list_hardware,
                                                mock_make_server,
@@ -367,14 +385,14 @@ class TestBaseAgent(test_base.BaseTestCase):
         mock_dispatch.assert_has_calls(expected_dispatch_calls)
         mock_sleep.assert_has_calls(expected_sleep_calls)
 
-    @mock.patch('ironic_python_agent.hardware_managers.cna._detect_cna_card',
-                autospec=True)
+    @mock.patch.object(hardware, 'load_managers', autospec=True)
     @mock.patch.object(time, 'sleep', autospec=True)
+    @mock.patch.object(agent.IronicPythonAgent, '_wait_for_interface',
+                       autospec=True)
+    @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
     @mock.patch('wsgiref.simple_server.make_server', autospec=True)
-    @mock.patch.object(hardware, '_check_for_iscsi', autospec=True)
-    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info')
-    def test_run_with_sleep(self, mock_check_for_iscsi, mock_list_hardware,
-                            mock_make_server, mock_sleep, mock_cna):
+    def test_run_with_sleep(self, mock_make_server, mock_dispatch,
+                            mock_load_managers, mock_sleep, mock_wait):
         CONF.set_override('inspection_callback_url', '', enforce_type=True)
         wsgi_server = mock_make_server.return_value
         wsgi_server.start.side_effect = KeyboardInterrupt()
@@ -390,7 +408,6 @@ class TestBaseAgent(test_base.BaseTestCase):
                 'heartbeat_timeout': 300
             }
         }
-        mock_cna.return_value = False
         self.agent.run()
 
         listen_addr = agent.Host('192.0.2.1', 9999)
@@ -403,7 +420,9 @@ class TestBaseAgent(test_base.BaseTestCase):
 
         self.agent.heartbeater.start.assert_called_once_with()
         mock_sleep.assert_called_once_with(10)
-        self.assertTrue(mock_check_for_iscsi.called)
+        self.assertTrue(mock_load_managers.called)
+        self.assertTrue(mock_wait.called)
+        mock_dispatch.assert_called_once_with('list_hardware_info')
 
     def test_async_command_success(self):
         result = base.AsyncCommandResult('foo_command', {'fail': False},
@@ -493,7 +512,7 @@ class TestBaseAgent(test_base.BaseTestCase):
 
 @mock.patch.object(hardware.GenericHardwareManager, '_wait_for_disks',
                    lambda self: None)
-class TestAgentStandalone(test_base.BaseTestCase):
+class TestAgentStandalone(ironic_agent_base.IronicAgentTest):
 
     def setUp(self):
         super(TestAgentStandalone, self).setUp()
@@ -511,8 +530,13 @@ class TestAgentStandalone(test_base.BaseTestCase):
                                              'agent_ipmitool',
                                              True)
 
+    @mock.patch.object(hardware, '_check_for_iscsi', mock.Mock())
+    @mock.patch(
+        'ironic_python_agent.hardware_managers.cna._detect_cna_card',
+        mock.Mock())
     @mock.patch('wsgiref.simple_server.make_server', autospec=True)
-    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info')
+    @mock.patch.object(hardware.HardwareManager, 'list_hardware_info',
+                       autospec=True)
     def test_run(self, mock_list_hardware, mock_make_server):
         wsgi_server = mock_make_server.return_value
         wsgi_server.start.side_effect = KeyboardInterrupt()
@@ -546,7 +570,7 @@ class TestAgentStandalone(test_base.BaseTestCase):
                    lambda self: None)
 @mock.patch.object(socket, 'gethostbyname', autospec=True)
 @mock.patch.object(utils, 'execute', autospec=True)
-class TestAdvertiseAddress(test_base.BaseTestCase):
+class TestAdvertiseAddress(ironic_agent_base.IronicAgentTest):
     def setUp(self):
         super(TestAdvertiseAddress, self).setUp()
 
